..
    Copyright (C) 2019 Esteban J. Garcia Gabancho.

    Invenio-SAML is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

==============
 Invenio-SAML
==============

.. image:: https://github.com/inveniosoftware/invenio-saml/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-saml/actions?query=workflow%3ACI

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-saml.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-saml

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-saml.svg
        :target: https://github.com/inveniosoftware/invenio-saml/releases

.. image:: https://img.shields.io/pypi/dm/invenio-saml.svg
        :target: https://pypi.python.org/pypi/invenio-saml

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-saml.svg
        :target: https://github.com/inveniosoftware/invenio-saml/blob/master/LICENSE

Invenio module that provides SAML integration.

TODO: Please provide feature overview of module

Further documentation is available on
https://invenio-saml.readthedocs.io/
